@@ -60,10 +60,15 @@ REGISTER_LAST = object()
 # combination of uppercase letters, lowercase letters, numbers, periods
 # (.), hyphens (-), and underscores (_).
 VALID_BUCKET = re.compile(r'^[a-zA-Z0-9.\-_]{1,255}$')
-VALID_S3_ARN = re.compile(
+_ACCESSPOINT_ARN = (
     r'^arn:(aws).*:s3:[a-z\-0-9]+:[0-9]{12}:accesspoint[/:]'
     r'[a-zA-Z0-9\-]{1,63}$'
 )
+_OUTPOST_ARN = (
+    r'^arn:(aws).*:s3-outposts:[a-z\-0-9]+:[0-9]{12}:outpost[/:]'
+    r'[a-zA-Z0-9\-]{1,63}[/:]accesspoint[/:][a-zA-Z0-9\-]{1,63}$'
+)
+VALID_S3_ARN = re.compile('|'.join([_ACCESSPOINT_ARN, _OUTPOST_ARN]))
 VERSION_ID_SUFFIX = re.compile(r'\?versionId=[^\s]+$')
 
 SERVICE_NAME_ALIASES = {
@@ -844,6 +849,7 @@ class ClientMethodAlias(object):
         return getattr(client, self._actual)
 
 
+# TODO: Remove this class as it is no longer used
 class HeaderToHostHoister(object):
     """Takes a header and moves it to the front of the hoststring.
     """
@@ -1040,6 +1046,8 @@ BUILTIN_HANDLERS = [
      inject_presigned_url_rds),
     ('before-call.rds.CreateDBInstanceReadReplica',
      inject_presigned_url_rds),
+    ('before-call.rds.StartDBInstanceAutomatedBackupsReplication',
+     inject_presigned_url_rds),
 
     # RDS PresignedUrl documentation customizations
     ('docs.*.rds.CopyDBClusterSnapshot.complete-section',
@@ -1050,6 +1058,8 @@ BUILTIN_HANDLERS = [
      AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
     ('docs.*.rds.CreateDBInstanceReadReplica.complete-section',
      AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
+    ('docs.*.rds.StartDBInstanceAutomatedBackupsReplication.complete-section',
+     AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
 
     #############
     # Neptune
@@ -1070,16 +1080,14 @@ BUILTIN_HANDLERS = [
     #############
     ('before-call.docdb.CopyDBClusterSnapshot',
      inject_presigned_url_rds),
+    ('before-call.docdb.CreateDBCluster',
+     inject_presigned_url_rds),
 
     # DocDB PresignedUrl documentation customizations
     ('docs.*.docdb.CopyDBClusterSnapshot.complete-section',
      AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
-
-    #############
-    # S3 Control
-    #############
-    ('before-call.s3-control.*',
-     HeaderToHostHoister('x-amz-account-id').hoist),
+    ('docs.*.docdb.CreateDBCluster.complete-section',
+     AutoPopulatedParam('PreSignedUrl').document_auto_populated_param),
 
     ###########
     # SMS Voice
